===============
 jymysql
===============

Installation
============

* `Install <https://odoo-development.readthedocs.io/en/latest/odoo/usage/install-module.html>`__ this module in a usual way
* {OPTIONAL }`Activate longpolling <https://odoo-development.readthedocs.io/en/latest/admin/longpolling.html>`__
* {Additional notes if any}

Configuration
=============

{Instruction how to configure the module.}

* `Enable technical features <https://odoo-development.readthedocs.io/en/latest/odoo/usage/technical-features.html>`__
* Open menu ``{Menu} >> {Submenu} >> {Subsubmenu}``
* Click ``[{Button Name}]``

Usage
=====

{Instruction for daily usage. It should describe how to check that module works. What shall user do and what would user get.}
* Open menu ``{Menu} >> {Submenu} >> {Subsubmenu}``
* Click ``[{Button Name}]``

Uninstallation
==============

{Optional section for uninstallation notes. Delete it if you don't have notes for uninstallation.}